# from ..auth.oauth2 import TokenResponse as TokenResponse
from ..object.cloneable import Cloneable as Cloneable

# from ..object.collaboration_allowlist import CollaborationAllowlist as CollaborationAllowlist
# from ..object.collaboration_whitelist import CollaborationWhitelist as CollaborationWhitelist
# from ..object.events import Events as Events
# from ..object.search import Search as Search
# from ..object.trash import Trash as Trash
from ..object.user import User as User
from ..object.folder import Folder as Folder
from ..object.file import File as File
from ..auth.oauth2 import OAuth2 as OAuth2

# from ..pagination.limit_offset_based_object_collection import LimitOffsetBasedObjectCollection as LimitOffsetBasedObjectCollection
# from ..pagination.marker_based_object_collection import MarkerBasedObjectCollection as MarkerBasedObjectCollection
# from ..session.session import AuthorizedSession as AuthorizedSession, Session as Session
# from ..util.api_call_decorator import api_call as api_call
# from ..util.deprecation_decorator import deprecated as deprecated
# from ..util.shared_link import get_shared_link_header as get_shared_link_header
from _typeshed import Incomplete

class Client(Cloneable):
    _auth: OAuth2
    # unauthorized_session_class = Session
    # authorized_session_class = AuthorizedSession
    def __init__(self, oauth, session: Incomplete | None = None) -> None: ...
    @property
    def auth(self) -> OAuth2: ...
    @property
    def session(self): ...
    @property
    def translator(self): ...
    def folder(self, folder_id): ...
    def root_folder(self): ...
    def file(self, file_id): ...
    def file_version(self, version_id): ...
    def upload_session(self, session_id): ...
    def comment(self, comment_id): ...
    def user(self, user_id: str = "me") -> User: ...
    def invite(self, invite_id): ...
    def email_alias(self, alias_id): ...
    def group(self, group_id): ...
    def collaboration(self, collab_id): ...
    def collaboration_whitelist(self): ...
    def collaboration_whitelist_entry(self, entry_id): ...
    def collaboration_whitelist_exempt_target(self, exemption_id): ...
    def collaboration_allowlist(self): ...
    def collaboration_allowlist_entry(self, entry_id): ...
    def collaboration_allowlist_exempt_target(self, exemption_id): ...
    def trash(self): ...
    def legal_hold_policy(self, policy_id): ...
    def legal_hold_policy_assignment(self, policy_assignment_id): ...
    def legal_hold(self, hold_id): ...
    def create_legal_hold_policy(
        self,
        policy_name,
        description: Incomplete | None = None,
        filter_starting_at: Incomplete | None = None,
        filter_ending_at: Incomplete | None = None,
        is_ongoing: Incomplete | None = None,
    ): ...
    def get_legal_hold_policies(
        self,
        policy_name: Incomplete | None = None,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def collection(self, collection_id): ...
    def collections(
        self,
        limit: Incomplete | None = None,
        offset: int = 0,
        fields: Incomplete | None = None,
    ): ...
    def enterprise(self, enterprise_id): ...
    def get_current_enterprise(self): ...
    def users(
        self,
        limit: Incomplete | None = None,
        offset: int = 0,
        filter_term: Incomplete | None = None,
        user_type: Incomplete | None = None,
        fields: Incomplete | None = None,
        use_marker: bool = False,
        marker: Incomplete | None = None,
    ): ...
    def search(self): ...
    def events(self): ...
    def group_membership(self, group_membership_id): ...
    def get_groups(
        self,
        name: Incomplete | None = None,
        limit: Incomplete | None = None,
        offset: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def webhook(self, webhook_id): ...
    def create_webhook(self, target, triggers, address): ...
    def get_webhooks(
        self,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def create_group(
        self,
        name,
        provenance: Incomplete | None = None,
        external_sync_identifier: Incomplete | None = None,
        description: Incomplete | None = None,
        invitability_level: Incomplete | None = None,
        member_viewability_level: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def storage_policy(self, policy_id): ...
    def storage_policy_assignment(self, assignment_id): ...
    def get_storage_policies(
        self,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def terms_of_service(self, tos_id): ...
    def terms_of_service_user_status(self, tos_user_status_id): ...
    def get_terms_of_services(
        self,
        tos_type: Incomplete | None = None,
        limit: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def task(self, task_id): ...
    def task_assignment(self, assignment_id): ...
    def retention_policy(self, retention_id): ...
    def file_version_retention(self, retention_id): ...
    def retention_policy_assignment(self, assignment_id): ...
    def create_retention_policy(
        self,
        policy_name,
        disposition_action,
        retention_length,
        can_owner_extend_retention: Incomplete | None = None,
        are_owners_notified: Incomplete | None = None,
        custom_notification_recipients: Incomplete | None = None,
    ): ...
    def get_retention_policies(
        self,
        policy_name: Incomplete | None = None,
        policy_type: Incomplete | None = None,
        user: Incomplete | None = None,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def create_terms_of_service(self, status, tos_type, text): ...
    def get_file_version_retentions(
        self,
        target_file: Incomplete | None = None,
        file_version: Incomplete | None = None,
        policy: Incomplete | None = None,
        disposition_action: Incomplete | None = None,
        disposition_before: Incomplete | None = None,
        disposition_after: Incomplete | None = None,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def web_link(self, web_link_id): ...
    def get_recent_items(
        self,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
        **collection_kwargs
    ): ...
    def get_shared_item(self, shared_link, password: Incomplete | None = None): ...
    def make_request(self, method, url, **kwargs): ...
    def create_user(self, name, login: Incomplete | None = None, **user_attributes): ...
    def get_pending_collaborations(
        self,
        limit: Incomplete | None = None,
        offset: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def downscope_token(
        self,
        scopes,
        item: Incomplete | None = None,
        additional_data: Incomplete | None = None,
        shared_link: Incomplete | None = None,
    ): ...
    def clone(self, session: Incomplete | None = None): ...
    def get_url(self, endpoint, *args): ...
    def device_pinner(self, device_pin_id): ...
    def device_pinners(
        self,
        enterprise: Incomplete | None = None,
        direction: Incomplete | None = None,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def metadata_cascade_policy(self, policy_id): ...
    def metadata_template(self, scope, template_key): ...
    def metadata_template_by_id(self, template_id): ...
    def get_metadata_templates(
        self,
        scope: str = "enterprise",
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def create_metadata_template(
        self,
        display_name,
        fields,
        template_key: Incomplete | None = None,
        hidden: bool = False,
        scope: str = "enterprise",
        copy_instance_on_item_copy: bool = False,
    ): ...
    def download_zip(self, name, items, writeable_stream): ...
    def folder_lock(self, folder_lock_id): ...
    def sign_request(self, sign_request_id): ...
    def create_sign_request(
        self,
        files,
        signers,
        parent_folder_id,
        prefill_tags: Incomplete | None = None,
        are_reminders_enabled: Incomplete | None = None,
        are_text_signatures_enabled: Incomplete | None = None,
        days_valid: Incomplete | None = None,
        email_message: Incomplete | None = None,
        email_subject: Incomplete | None = None,
        external_id: Incomplete | None = None,
        is_document_preparation_needed: Incomplete | None = None,
    ): ...
    def get_sign_requests(
        self,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...



# from ..exception import BoxAPIException as BoxAPIException
# from ..pagination.marker_based_dict_collection import MarkerBasedDictCollection as MarkerBasedDictCollection
# from ..pagination.marker_based_object_collection import MarkerBasedObjectCollection as MarkerBasedObjectCollection
# from ..util.api_call_decorator import api_call as api_call
# from ..util.default_arg_value import SDK_VALUE_NOT_SET as SDK_VALUE_NOT_SET
from .base_item import BaseItem as BaseItem

# from .metadata import Metadata as Metadata
from _typeshed import Incomplete
from boxsdk.util.text_enum import TextEnum as TextEnum

class ClassificationType(TextEnum):
    PUBLIC: str
    INTERNAL: str
    CONFIDENTIAL: str
    NONE: str

class Item(BaseItem):
    name: str
    modified_at: str
    id: str
    object_id: str

    def update_info(self, data, etag: Incomplete | None = None): ...
    def get(
        self, fields: Incomplete | None = None, etag: Incomplete | None = None
    ) -> "Item": ...
    def create_shared_link(
        self,
        access: Incomplete | None = None,
        etag: Incomplete | None = None,
        unshared_at=...,
        allow_download: Incomplete | None = None,
        allow_preview: Incomplete | None = None,
        password: Incomplete | None = None,
        vanity_name: Incomplete | None = None,
        **kwargs
    ): ...
    def get_shared_link(
        self,
        access: Incomplete | None = None,
        etag: Incomplete | None = None,
        unshared_at=...,
        allow_download: Incomplete | None = None,
        allow_preview: Incomplete | None = None,
        password: Incomplete | None = None,
        vanity_name: Incomplete | None = None,
        **kwargs
    ): ...
    def remove_shared_link(self, etag: Incomplete | None = None, **kwargs): ...
    def delete(
        self, params: Incomplete | None = None, etag: Incomplete | None = None
    ): ...
    def metadata(self, scope: str = "global", template: str = "properties"): ...
    def get_all_metadata(self): ...
    def get_watermark(self): ...
    def apply_watermark(self): ...
    def delete_watermark(self): ...
    def collaborate(
        self,
        accessible_by,
        role,
        can_view_path: Incomplete | None = None,
        notify: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def collaborate_with_login(
        self,
        login,
        role,
        can_view_path: Incomplete | None = None,
        notify: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def get_collaborations(
        self,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def add_classification(self, classification): ...
    def update_classification(self, classification): ...
    def set_classification(self, classification): ...
    def get_classification(self): ...
    def remove_classification(self): ...



from ..util.translator import Translator as Translator
from _typeshed import Incomplete

class BaseAPIJSONObjectMeta(type):
    def __init__(cls, name, bases, attrs) -> None: ...

class BaseAPIJSONObject:
    def __init__(self, response_object: Incomplete | None = None, **kwargs) -> None: ...
    def __getitem__(self, item): ...
    def __contains__(self, item) -> bool: ...
    def __iter__(self): ...
    @property
    def object_type(self): ...
    @classmethod
    def untranslated_fields(cls): ...
    @property
    def response_object(self): ...



# from ..pagination.limit_offset_based_object_collection import LimitOffsetBasedObjectCollection as LimitOffsetBasedObjectCollection
# from ..pagination.marker_based_object_collection import MarkerBasedObjectCollection as MarkerBasedObjectCollection
# from ..util.api_call_decorator import api_call as api_call
from .base_object import BaseObject as BaseObject
from _typeshed import Incomplete

class User(BaseObject):
    space_used: float
    space_amount: float
    def add_email_alias(self, email): ...
    def get_email_aliases(
        self, limit: Incomplete | None = None, fields: Incomplete | None = None
    ): ...
    def remove_email_alias(self, email_alias): ...
    def transfer_content(
        self,
        destination_user,
        notify: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def get(
        self, fields: Incomplete | None = None, headers: Incomplete | None = None
    ) -> "User": ...
    def get_storage_policy_assignment(self): ...
    def get_group_memberships(
        self,
        limit: Incomplete | None = None,
        offset: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def get_avatar(self): ...
    def delete(self, notify: bool = True, force: bool = False): ...



from ..exception import BoxValueError as BoxValueError
from ..util.api_call_decorator import api_call as api_call
from ..util.default_arg_value import SDK_VALUE_NOT_SET as SDK_VALUE_NOT_SET
from .base_object import BaseObject as BaseObject
from _typeshed import Incomplete

class BaseItem(BaseObject):
    def copy(self, parent_folder, name: Incomplete | None = None): ...
    def move(self, parent_folder, name: Incomplete | None = None): ...
    def rename(self, name): ...
    def create_shared_link(self, **kwargs): ...
    def get_shared_link(self, **kwargs): ...
    def remove_shared_link(self, **kwargs): ...
    def add_to_collection(self, collection): ...
    def remove_from_collection(self, collection): ...
    @staticmethod
    def validate_item_id(item_id) -> None: ...



from .cloneable import Cloneable as Cloneable
from _typeshed import Incomplete

class BaseEndpoint(Cloneable):
    def __init__(self, session, **kwargs) -> None: ...
    @property
    def session(self): ...
    @property
    def translator(self): ...
    def get_url(self, endpoint, *args): ...
    def clone(self, session: Incomplete | None = None): ...



from _typeshed import Incomplete

class Cloneable:
    def as_user(self, user): ...
    def with_shared_link(self, shared_link, shared_link_password): ...
    def clone(self, session: Incomplete | None = None) -> None: ...
    @property
    def session(self) -> None: ...



from _typeshed import Incomplete
from typing import Iterable
from boxsdk.object.group import Group as Group
from boxsdk.object.item import Item as Item
from boxsdk.object.user import User as User
from boxsdk.pagination.limit_offset_based_object_collection import (
    LimitOffsetBasedObjectCollection as LimitOffsetBasedObjectCollection,
)
from boxsdk.pagination.marker_based_object_collection import (
    MarkerBasedObjectCollection as MarkerBasedObjectCollection,
)
from boxsdk.util.api_call_decorator import api_call as api_call
from boxsdk.util.text_enum import TextEnum as TextEnum

class FolderSyncState(TextEnum):
    IS_SYNCED: str
    NOT_SYNCED: str
    PARTIALLY_SYNCED: str

class _CollaborationType(TextEnum):
    USER: str
    GROUP: str

class _Collaborator:
    def __init__(self, collaborator) -> None: ...
    @property
    def access(self): ...
    @property
    def type(self): ...

class Folder(Item):
    def preflight_check(self, size, name): ...
    def create_upload_session(self, file_size, file_name): ...
    def get_chunked_uploader(self, file_path): ...
    def get(
        self, fields: Incomplete | None = None, etag: Incomplete | None = None
    ) -> "Folder": ...
    def get_items(
        self,
        limit: Incomplete | None = None,
        offset: int = 0,
        marker: Incomplete | None = None,
        use_marker: bool = False,
        sort: Incomplete | None = None,
        direction: Incomplete | None = None,
        fields: Incomplete | None = None,
    ) -> Iterable[Item]: ...
    def upload_stream(
        self,
        file_stream,
        file_name,
        file_description: Incomplete | None = None,
        preflight_check: bool = False,
        preflight_expected_size: int = 0,
        upload_using_accelerator: bool = False,
        content_created_at: Incomplete | None = None,
        content_modified_at: Incomplete | None = None,
        additional_attributes: Incomplete | None = None,
        sha1: Incomplete | None = None,
        etag: Incomplete | None = None,
    ): ...
    def upload(
        self,
        file_path: Incomplete | None = None,
        file_name: Incomplete | None = None,
        file_description: Incomplete | None = None,
        preflight_check: bool = False,
        preflight_expected_size: int = 0,
        upload_using_accelerator: bool = False,
        content_created_at: Incomplete | None = None,
        content_modified_at: Incomplete | None = None,
        additional_attributes: Incomplete | None = None,
        sha1: Incomplete | None = None,
        etag: Incomplete | None = None,
    ): ...
    def create_subfolder(self, name): ...
    def update_sync_state(self, sync_state): ...
    def add_collaborator(
        self, collaborator, role, notify: bool = False, can_view_path: bool = False
    ): ...
    def create_web_link(
        self,
        target_url,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
    ): ...
    def delete(self, recursive: bool = True, etag: Incomplete | None = None): ...
    def get_metadata_cascade_policies(
        self,
        owner_enterprise: Incomplete | None = None,
        limit: Incomplete | None = None,
        marker: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def cascade_metadata(self, metadata_template): ...
    def create_lock(self): ...
    def get_locks(self): ...



# from ..util.api_call_decorator import api_call as api_call
from .base_api_json_object import BaseAPIJSONObject as BaseAPIJSONObject
from .base_endpoint import BaseEndpoint as BaseEndpoint
from _typeshed import Incomplete

class BaseObject(BaseEndpoint, BaseAPIJSONObject):
    def __init__(
        self, session, object_id, response_object: Incomplete | None = None
    ) -> None: ...
    def get_url(self, *args): ...
    def get_type_url(self): ...
    @property
    def object_id(self): ...
    def get(
        self, fields: Incomplete | None = None, headers: Incomplete | None = None
    ): ...
    def update_info(
        self,
        data,
        params: Incomplete | None = None,
        headers: Incomplete | None = None,
        **kwargs
    ): ...
    def delete(
        self, params: Incomplete | None = None, headers: Incomplete | None = None
    ): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __hash__(self): ...
    def clone(self, session: Incomplete | None = None): ...



# from ..pagination.limit_offset_based_object_collection import LimitOffsetBasedObjectCollection as LimitOffsetBasedObjectCollection
# from ..pagination.marker_based_object_collection import MarkerBasedObjectCollection as MarkerBasedObjectCollection
# from ..util.api_call_decorator import api_call as api_call
# from ..util.deprecation_decorator import deprecated as deprecated
from typing import List
from .item import Item as Item
from .folder import Folder as Folder
from _typeshed import Incomplete

class File(Item):
    path_collection: dict[str, List[Folder]]
    def preflight_check(self, size, name: Incomplete | None = None): ...
    def create_upload_session(self, file_size, file_name: Incomplete | None = None): ...
    def get_chunked_uploader(self, file_path, rename_file: bool = False): ...
    def content(
        self,
        file_version: Incomplete | None = None,
        byte_range: Incomplete | None = None,
    ): ...
    def download_to(
        self,
        writeable_stream,
        file_version: Incomplete | None = None,
        byte_range: Incomplete | None = None,
    ) -> None: ...
    def get(
        self, fields: Incomplete | None = None, etag: Incomplete | None = None
    ) -> "File": ...
    def get_download_url(self, file_version: Incomplete | None = None): ...
    def update_contents_with_stream(
        self,
        file_stream,
        etag: Incomplete | None = None,
        preflight_check: bool = False,
        preflight_expected_size: int = 0,
        upload_using_accelerator: bool = False,
        file_name: Incomplete | None = None,
        content_modified_at: Incomplete | None = None,
        additional_attributes: Incomplete | None = None,
        sha1: Incomplete | None = None,
    ): ...
    def update_contents(
        self,
        file_path,
        etag: Incomplete | None = None,
        preflight_check: bool = False,
        preflight_expected_size: int = 0,
        upload_using_accelerator: bool = False,
        file_name: Incomplete | None = None,
        content_modified_at: Incomplete | None = None,
        additional_attributes: Incomplete | None = None,
        sha1: Incomplete | None = None,
    ): ...
    def lock(
        self, prevent_download: bool = False, expire_time: Incomplete | None = None
    ): ...
    def unlock(self): ...
    def get_shared_link_download_url(
        self,
        access: Incomplete | None = None,
        etag: Incomplete | None = None,
        unshared_at: Incomplete | None = None,
        allow_preview: Incomplete | None = None,
        password: Incomplete | None = None,
        vanity_name: Incomplete | None = None,
    ): ...
    def get_comments(
        self,
        limit: Incomplete | None = None,
        offset: int = 0,
        fields: Incomplete | None = None,
    ): ...
    def add_comment(self, message): ...
    def create_task(
        self,
        message: Incomplete | None = None,
        due_at: Incomplete | None = None,
        action: str = "review",
        completion_rule: Incomplete | None = None,
    ): ...
    def get_tasks(self, fields: Incomplete | None = None): ...
    def get_previous_versions(
        self,
        limit: Incomplete | None = None,
        offset: Incomplete | None = None,
        fields: Incomplete | None = None,
    ): ...
    def promote_version(self, file_version): ...
    def delete_version(self, file_version, etag: Incomplete | None = None): ...
    def get_embed_url(self): ...
    def get_representation_info(self, rep_hints: Incomplete | None = None): ...
    def get_thumbnail(
        self,
        extension: str = "png",
        min_width: Incomplete | None = None,
        min_height: Incomplete | None = None,
        max_width: Incomplete | None = None,
        max_height: Incomplete | None = None,
    ): ...
    def get_thumbnail_representation(self, dimensions, extension: str = "png"): ...
    def copy(
        self,
        parent_folder,
        name: Incomplete | None = None,
        file_version: Incomplete | None = None,
    ): ...



from ..config import API as API
from ..exception import (
    BoxAPIException as BoxAPIException,
    BoxOAuthException as BoxOAuthException,
)
from ..object.base_api_json_object import BaseAPIJSONObject as BaseAPIJSONObject
from ..session.session import Session as Session
from ..util.json import is_json_response as is_json_response
from ..util.text_enum import TextEnum as TextEnum
from _typeshed import Incomplete
from collections.abc import Generator

class TokenScope(TextEnum):
    ITEM_READ: str
    ITEM_READWRITE: str
    ITEM_PREVIEW: str
    ITEM_UPLOAD: str
    ITEM_SHARE: str
    ITEM_DELETE: str
    ITEM_DOWNLOAD: str

class TokenResponse(BaseAPIJSONObject): ...

class OAuth2:
    def __init__(
        self,
        client_id,
        client_secret,
        store_tokens: Incomplete | None = None,
        box_device_id: str = "0",
        box_device_name: str = "",
        access_token: Incomplete | None = None,
        refresh_token: Incomplete | None = None,
        session: Incomplete | None = None,
        refresh_lock: Incomplete | None = None,
    ) -> None: ...
    @property
    def access_token(self): ...
    @property
    def closed(self): ...
    @property
    def api_config(self): ...
    def get_authorization_url(self, redirect_url): ...
    def authenticate(self, auth_code): ...
    def refresh(self, access_token_to_refresh): ...
    def send_token_request(
        self, data, access_token, expect_refresh_token: bool = True
    ): ...
    def revoke(self) -> None: ...
    def close(self, revoke: bool = True) -> None: ...
    def closing(self, **close_kwargs) -> Generator[Incomplete, None, None]: ...
